skoolbuilder — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# skoolbuilder

Build the skool and its cast of characters.

class `skoolbuilder.` `SkoolBuilder`(path, verbose=True)

  Builds a skool and its cast from the contents of ini files.

  `build_skool`(skool)

    Build a skool from the contents of the ini files.

    Parameters: | skool (`Skool`) – The skool to build.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »